@@ -3,7 +3,7 @@ package Taxon::Parse;
 use strict;
 use warnings;
 
-our $VERSION = 0.010;
+our $VERSION = '0.011';
 
 sub new {
   my $class = shift;
@@ -121,6 +121,11 @@ __END__
 
 Taxon::Parse - Parse bio Taxon names
 
+=for html
+
+<a href="https://travis-ci.org/wollmers/Taxon-Parse"><img src="https://travis-ci.org/wollmers/Taxon-Parse.png" alt="Taxon-Parse"></a>
+<a href='https://coveralls.io/r/wollmers/Taxon-Parse?branch=master'><img src='https://coveralls.io/repos/wollmers/Taxon-Parse/badge.png?branch=master' alt='Coverage Status' /></a>
+
 =head1 SYNOPSIS
 
  use Taxon::Parse;
